@@ -9,9 +9,22 @@ class Builder(object):
     def __init__(self):
         pass
 
-    def read(self, infile):
+    def read(self, ucdfile, emojifile):
+        emoji = set()
+        for line in emojifile:
+            m = re.match('([0-9A-F ]+); fully-qualified\s+#.*E\d+.\d+ (.+)', line)
+
+            if not m:
+                continue
+
+            cp = m.group(1).strip()
+            if cp.find(' ') > 0:
+                continue
+
+            emoji.add(int(cp, 16))
+
         names = []
-        for line in infile:
+        for line in ucdfile:
             if line.startswith('#'):
                 continue
             line = line.strip()
@@ -24,6 +37,11 @@ class Builder(object):
             if name[0] == '<':
                 continue
 
+            cp = int(codepoint, 16)
+            if cp in emoji:
+                emoji.remove(cp)
+                continue
+
             names.append((codepoint, name))
 
         return names
@@ -46,11 +64,13 @@ if __name__ == '__main__':
     import argparse
 
     parser = argparse.ArgumentParser(description='build')
-    parser.add_argument('infile', type=argparse.FileType('r'),
-                        help='input file')
+    parser.add_argument('ucdfile', type=argparse.FileType('r'),
+                        help='UnicodeData.txt')
+    parser.add_argument('emojifile', type=argparse.FileType('r'),
+                        help='emoji-test.txt')
     args = parser.parse_args()
 
     builder = Builder()
     # FIXME: argparse.FileType(encoding=...) is available since Python 3.4
-    data = builder.read(io.open(args.infile.name, encoding='utf_8_sig'))
+    data = builder.read(io.open(args.ucdfile.name, encoding='utf_8_sig'), io.open(args.emojifile.name, encoding='utf_8_sig'))
     builder.write(data)
