@@ -1,3 +1,4 @@
+/* exported main settings */
 // -*- Mode: js; indent-tabs-mode: nil; c-basic-offset: 4; tab-width: 4 -*-
 //
 // Copyright (c) 2013 Giovanni Campagna <scampa.giovanni@gmail.com>
@@ -26,92 +27,94 @@
 
 pkg.initGettext();
 pkg.initFormat();
-pkg.require({ 
-    'Gdk': '3.0',
+pkg.require({
+    'Gdk': '4.0',
     'Gio': '2.0',
     'GLib': '2.0',
     'GObject': '2.0',
-    'Gtk': '3.0',
-    'Handy': '1',
+    'Gtk': '4.0',
+    'Adw': '1',
+    'GnomeDesktop': '4.0',
 });
 
-const {GLib, Gio, GObject, Gtk, Handy} = imports.gi;
+const { GLib, Gio, GObject, Adw } = imports.gi;
+
+const { CharactersView } = imports.charactersView;
+const { Sidebar } = imports.sidebar;
+const { MainWindow } = imports.window;
 
 const Util = imports.util;
-const Window = imports.window;
-
+const SearchProvider = imports.searchProvider;
 var settings = null;
-var application_id = pkg.name;
-
-function initEnvironment() {
-    window.getApp = function() {
-        return Gio.Application.get_default();
-    };
-}
 
 var MyApplication = GObject.registerClass({
-},class MyApplication extends Gtk.Application {
-    _init () {
-        super._init({ application_id: application_id,
-                      flags: Gio.ApplicationFlags.FLAGS_NONE });
-
+}, class MyApplication extends Adw.Application {
+    _init() {
+        super._init({
+            application_id: pkg.name,
+            flags: Gio.ApplicationFlags.FLAGS_NONE,
+            resource_base_path: '/org/gnome/Characters',
+        });
         GLib.set_application_name(_('Characters'));
+
+        this._searchProvider = new SearchProvider.SearchProvider(this);
     }
 
-    _onQuit () {
+    get window() {
+        return this._appwindow;
+    }
+
+    _onQuit() {
         this.quit();
     }
 
-    _onSearch (action, parameter) {
-        const window = new Window.MainWindow({ application: this });
-        window.setSearchKeywords(parameter.get_strv());
-        window.show();
-    }
-
-    vfunc_startup () {
+    vfunc_startup() {
         super.vfunc_startup();
 
-        let theme = Gtk.IconTheme.get_default();
-        theme.add_resource_path('/org/gnome/Characters/icons');
+        this.get_style_manager().set_color_scheme(Adw.ColorScheme.PREFER_LIGHT);
 
-        Util.loadStyleSheet('/org/gnome/Characters/application.css');
-
-        Util.initActions(this,
-                         [{ name: 'quit',
-                            activate: this._onQuit },
-                          { name: 'search',
-                            activate: this._onSearch,
-                            parameter_type: new GLib.VariantType('as') }]);
+        Util.initActions(this, [
+            { name: 'quit', activate: this._onQuit },
+        ]);
         this.set_accels_for_action('app.quit', ['<Primary>q']);
         this.set_accels_for_action('win.find', ['<Primary>f']);
         this.set_accels_for_action('win.show-primary-menu', ['F10']);
         this.set_accels_for_action('win.show-help-overlay', ['<Primary>question']);
 
         settings = Util.getSettings('org.gnome.Characters',
-                                    '/org/gnome/Characters/');
+            '/org/gnome/Characters/');
 
-        log("Characters Application started");
+        log('Characters Application started');
+    }
+
+    vfunc_dbus_register(connection, path) {
+        const searchProviderPath = `${path}/SearchProvider`;
+        super.vfunc_dbus_register(connection, searchProviderPath);
+        this._searchProvider.export(connection, searchProviderPath);
+        return true;
     }
 
     vfunc_activate() {
-        if (!this._appwindow) {
-            this._appwindow = new Window.MainWindow({ application: this });
-        }
-        Handy.init();
+        if (!this._appwindow)
+            this._appwindow = new MainWindow(this);
+
+        if (pkg.name.endsWith('Devel'))
+            this._appwindow.add_css_class('devel');
 
         this._appwindow.present();
-        log("Characters Application activated");
+        log('Characters Application activated');
     }
 
     vfunc_shutdown() {
-        log("Characters Application exiting");
+        log('Characters Application exiting');
 
         super.vfunc_shutdown();
     }
 });
 
 function main(argv) {
-    initEnvironment();
+    GObject.type_ensure(CharactersView.$gtype);
+    GObject.type_ensure(Sidebar.$gtype);
 
-    return (new MyApplication()).run(argv);
+    return new MyApplication().run(argv);
 }
